package sun.util.locale.provider;

import java.lang.ref.SoftReference;
import sun.util.resources.ParallelListResourceBundle;
import java.text.MessageFormat;
import java.util.Calendar;
import java.util.Map;
import java.util.Iterator;
import sun.util.calendar.ZoneInfo;
import java.util.LinkedHashSet;
import java.util.Set;
import sun.util.resources.TimeZoneNamesBundle;
import java.util.Objects;
import sun.util.resources.OpenListResourceBundle;
import java.util.ResourceBundle;
import java.lang.ref.Reference;
import java.util.concurrent.ConcurrentHashMap;
import java.lang.ref.ReferenceQueue;
import java.util.concurrent.ConcurrentMap;
import sun.util.resources.LocaleData;
import java.util.Locale;

public class LocaleResources
{
    private final Locale locale;
    private final LocaleData localeData;
    private final LocaleProviderAdapter.Type type;
    private ConcurrentMap<String, LocaleResources.ResourceReference> cache;
    private ReferenceQueue<Object> referenceQueue;
    private static final String BREAK_ITERATOR_INFO = "BII.";
    private static final String CALENDAR_DATA = "CALD.";
    private static final String COLLATION_DATA_CACHEKEY = "COLD";
    private static final String DECIMAL_FORMAT_SYMBOLS_DATA_CACHEKEY = "DFSD";
    private static final String CURRENCY_NAMES = "CN.";
    private static final String LOCALE_NAMES = "LN.";
    private static final String TIME_ZONE_NAMES = "TZN.";
    private static final String ZONE_IDS_CACHEKEY = "ZID";
    private static final String CALENDAR_NAMES = "CALN.";
    private static final String NUMBER_PATTERNS_CACHEKEY = "NP";
    private static final String DATE_TIME_PATTERN = "DTP.";
    private static final Object NULLOBJECT;
    
    LocaleResources(ResourceBundleBasedAdapter resourceBundleBasedAdapter, Locale locale) {
        this.cache = new ConcurrentHashMap();
        this.referenceQueue = new ReferenceQueue();
        this.locale = locale;
        this.localeData = resourceBundleBasedAdapter.getLocaleData();
        this.type = ((LocaleProviderAdapter)resourceBundleBasedAdapter).getAdapterType();
    }
    
    private void removeEmptyReferences() {
        Reference<Object> poll;
        while ((poll = this.referenceQueue.poll()) != null) {
            this.cache.remove(((LocaleResources.ResourceReference)poll).getCacheKey());
        }
    }
    
    Object getBreakIteratorInfo(String s) {
        String string = "BII." + s;
        this.removeEmptyReferences();
        LocaleResources.ResourceReference resourceReference = (LocaleResources.ResourceReference)this.cache.get(string);
        Object o;
        if (resourceReference == null || (o = resourceReference.get()) == null) {
            o = this.localeData.getBreakIteratorInfo(this.locale).getObject(s);
            this.cache.put(string, new LocaleResources.ResourceReference(string, o, this.referenceQueue));
            return o;
        }
        return o;
    }
    
    int getCalendarData(String key) {
        String string = "CALD." + key;
        this.removeEmptyReferences();
        LocaleResources.ResourceReference resourceReference = (LocaleResources.ResourceReference)this.cache.get(string);
        Integer n;
        if (resourceReference == null || (n = (Integer)resourceReference.get()) == null) {
            ResourceBundle calendarData = this.localeData.getCalendarData(this.locale);
            if (calendarData.containsKey(key)) {
                n = Integer.valueOf(Integer.parseInt(calendarData.getString(key)));
            }
            else {
                n = Integer.valueOf(0);
            }
            this.cache.put(string, new LocaleResources.ResourceReference(string, n, this.referenceQueue));
        }
        return (int)n;
    }
    
    public String getCollationData() {
        String s = "Rule";
        String string = "";
        this.removeEmptyReferences();
        LocaleResources.ResourceReference resourceReference = (LocaleResources.ResourceReference)this.cache.get("COLD");
        if (resourceReference == null || (string = (String)resourceReference.get()) == null) {
            ResourceBundle collationData = this.localeData.getCollationData(this.locale);
            if (collationData.containsKey(s)) {
                string = collationData.getString(s);
            }
            this.cache.put("COLD", new LocaleResources.ResourceReference("COLD", string, this.referenceQueue));
            return string;
        }
        else {
            return string;
        }
    }
    
    public Object[] getDecimalFormatSymbolsData() {
        this.removeEmptyReferences();
        LocaleResources.ResourceReference resourceReference = (LocaleResources.ResourceReference)this.cache.get("DFSD");
        Object[] array;
        if (resourceReference == null || (array = (Object[])(Object[])resourceReference.get()) == null) {
            ResourceBundle numberFormatData = this.localeData.getNumberFormatData(this.locale);
            array = new Object[3];
            String unicodeLocaleType = this.locale.getUnicodeLocaleType("nu");
            if (unicodeLocaleType != null) {
                String string = unicodeLocaleType + ".NumberElements";
                if (numberFormatData.containsKey(string)) {
                    array[0] = numberFormatData.getStringArray(string);
                }
            }
            if (array[0] == null && numberFormatData.containsKey("DefaultNumberingSystem")) {
                String string2 = numberFormatData.getString("DefaultNumberingSystem") + ".NumberElements";
                if (numberFormatData.containsKey(string2)) {
                    array[0] = numberFormatData.getStringArray(string2);
                }
            }
            if (array[0] == null) {
                array[0] = numberFormatData.getStringArray("NumberElements");
            }
            this.cache.put("DFSD", new LocaleResources.ResourceReference("DFSD", array, this.referenceQueue));
            return array;
        }
        else {
            return array;
        }
    }
    
    public String getCurrencyName(String key) {
        Object o = null;
        String string = "CN." + key;
        this.removeEmptyReferences();
        LocaleResources.ResourceReference resourceReference = (LocaleResources.ResourceReference)this.cache.get(string);
        if (resourceReference != null && (o = resourceReference.get()) != null) {
            if (o.equals(LocaleResources.NULLOBJECT)) {
                o = null;
            }
            return (String)o;
        }
        else {
            OpenListResourceBundle currencyNames = this.localeData.getCurrencyNames(this.locale);
            if (currencyNames.containsKey(key)) {
                o = currencyNames.getObject(key);
                this.cache.put(string, new LocaleResources.ResourceReference(string, o, this.referenceQueue));
            }
            return (String)o;
        }
    }
    
    public String getLocaleName(String key) {
        Object o = null;
        String string = "LN." + key;
        this.removeEmptyReferences();
        LocaleResources.ResourceReference resourceReference = (LocaleResources.ResourceReference)this.cache.get(string);
        if (resourceReference != null && (o = resourceReference.get()) != null) {
            if (o.equals(LocaleResources.NULLOBJECT)) {
                o = null;
            }
            return (String)o;
        }
        else {
            OpenListResourceBundle localeNames = this.localeData.getLocaleNames(this.locale);
            if (localeNames.containsKey(key)) {
                o = localeNames.getObject(key);
                this.cache.put(string, new LocaleResources.ResourceReference(string, o, this.referenceQueue));
            }
            return (String)o;
        }
    }
    
    String[] getTimeZoneNames(String key) {
        String[] stringArray = null;
        String string = "TZN.." + key;
        this.removeEmptyReferences();
        LocaleResources.ResourceReference obj = (LocaleResources.ResourceReference)this.cache.get(string);
        if (Objects.isNull(obj) || Objects.isNull(stringArray = (String[])(String[])obj.get())) {
            TimeZoneNamesBundle timeZoneNames = this.localeData.getTimeZoneNames(this.locale);
            if (timeZoneNames.containsKey(key)) {
                stringArray = timeZoneNames.getStringArray(key);
                this.cache.put(string, new LocaleResources.ResourceReference(string, stringArray, this.referenceQueue));
            }
        }
        return stringArray;
    }
    
    Set<String> getZoneIDs() {
        this.removeEmptyReferences();
        LocaleResources.ResourceReference resourceReference = (LocaleResources.ResourceReference)this.cache.get("ZID");
        Set<String> keySet;
        if (resourceReference == null || (keySet = (Set)resourceReference.get()) == null) {
            keySet = this.localeData.getTimeZoneNames(this.locale).keySet();
            this.cache.put("ZID", new LocaleResources.ResourceReference("ZID", keySet, this.referenceQueue));
            return keySet;
        }
        return keySet;
    }
    
    String[][] getZoneStrings() {
        TimeZoneNamesBundle timeZoneNames = this.localeData.getTimeZoneNames(this.locale);
        Set<String> zoneIDs = this.getZoneIDs();
        LinkedHashSet<String> set = new LinkedHashSet();
        Iterator<Object> iterator = zoneIDs.iterator();
        while (iterator.hasNext()) {
            set.add(timeZoneNames.getStringArray((String)iterator.next()));
        }
        if (this.type == LocaleProviderAdapter.Type.CLDR) {
            Map<String, String> aliasTable = ZoneInfo.getAliasTable();
            for (String s : aliasTable.keySet()) {
                if (!zoneIDs.contains(s)) {
                    String key = (String)aliasTable.get(s);
                    if (zoneIDs.contains(key)) {
                        String[] stringArray = timeZoneNames.getStringArray(key);
                        stringArray[0] = s;
                        set.add(stringArray);
                    }
                    else {
                        continue;
                    }
                }
                else {
                    continue;
                }
            }
        }
        return (String[][])set.toArray(new String[0][]);
    }
    
    String[] getCalendarNames(String key) {
        String[] stringArray = null;
        String string = "CALN." + key;
        this.removeEmptyReferences();
        LocaleResources.ResourceReference resourceReference = (LocaleResources.ResourceReference)this.cache.get(string);
        if (resourceReference == null || (stringArray = (String[])(String[])resourceReference.get()) == null) {
            ResourceBundle dateFormatData = this.localeData.getDateFormatData(this.locale);
            if (dateFormatData.containsKey(key)) {
                stringArray = dateFormatData.getStringArray(key);
                this.cache.put(string, new LocaleResources.ResourceReference(string, stringArray, this.referenceQueue));
            }
        }
        return stringArray;
    }
    
    String[] getJavaTimeNames(String key) {
        String[] stringArray = null;
        String string = "CALN." + key;
        this.removeEmptyReferences();
        LocaleResources.ResourceReference resourceReference = (LocaleResources.ResourceReference)this.cache.get(string);
        if (resourceReference == null || (stringArray = (String[])(String[])resourceReference.get()) == null) {
            ResourceBundle javaTimeFormatData = this.getJavaTimeFormatData();
            if (javaTimeFormatData.containsKey(key)) {
                stringArray = javaTimeFormatData.getStringArray(key);
                this.cache.put(string, new LocaleResources.ResourceReference(string, stringArray, this.referenceQueue));
            }
        }
        return stringArray;
    }
    
    public String getDateTimePattern(int n, int n2, Calendar instance) {
        if (instance == null) {
            instance = Calendar.getInstance(this.locale);
        }
        return this.getDateTimePattern(null, n, n2, instance.getCalendarType());
    }
    
    public String getJavaTimeDateTimePattern(int n, int n2, String normalizeCalendarType) {
        normalizeCalendarType = CalendarDataUtility.normalizeCalendarType(normalizeCalendarType);
        String s = this.getDateTimePattern("java.time.", n, n2, normalizeCalendarType);
        if (s == null) {
            s = this.getDateTimePattern(null, n, n2, normalizeCalendarType);
            return s;
        }
        return s;
    }
    
    private String getDateTimePattern(String s, int n, int n2, String s2) {
        String s3 = null;
        String s4 = null;
        if (n >= 0) {
            if (s != null) {
                s3 = this.getDateTimePattern(s, "TimePatterns", n, s2);
            }
            if (s3 == null) {
                s3 = this.getDateTimePattern(null, "TimePatterns", n, s2);
            }
        }
        if (n2 >= 0) {
            if (s != null) {
                s4 = this.getDateTimePattern(s, "DatePatterns", n2, s2);
            }
            if (s4 == null) {
                s4 = this.getDateTimePattern(null, "DatePatterns", n2, s2);
            }
        }
        String s5;
        if (n >= 0) {
            if (n2 >= 0) {
                String pattern = null;
                if (s != null) {
                    pattern = this.getDateTimePattern(s, "DateTimePatterns", 0, s2);
                }
                if (pattern == null) {
                    pattern = this.getDateTimePattern(null, "DateTimePatterns", 0, s2);
                }
                int n3 = -1;
                switch (pattern.hashCode()) {
                    case -986855281: {
                        if (pattern.equals("{1} {0}")) {
                            n3 = 0;
                            break;
                        }
                        break;
                    }
                    case -1015484401: {
                        if (pattern.equals("{0} {1}")) {
                            n3 = 1;
                            break;
                        }
                        break;
                    }
                }
                switch (n3) {
                    case 0: {
                        s5 = s4 + " " + s3;
                        break;
                    }
                    case 1: {
                        s5 = s3 + " " + s4;
                        break;
                    }
                    default: {
                        s5 = MessageFormat.format(pattern, new Object[] { s3, s4 });
                        break;
                    }
                }
            }
            else {
                s5 = s3;
            }
        }
        else if (n2 >= 0) {
            s5 = s4;
        }
        else {
            throw new IllegalArgumentException("No date or time style specified");
        }
        return s5;
    }
    
    public String[] getNumberPatterns() {
        this.removeEmptyReferences();
        LocaleResources.ResourceReference resourceReference = (LocaleResources.ResourceReference)this.cache.get("NP");
        String[] stringArray;
        if (resourceReference == null || (stringArray = (String[])(String[])resourceReference.get()) == null) {
            stringArray = this.localeData.getNumberFormatData(this.locale).getStringArray("NumberPatterns");
            this.cache.put("NP", new LocaleResources.ResourceReference("NP", stringArray, this.referenceQueue));
            return stringArray;
        }
        return stringArray;
    }
    
    public ResourceBundle getJavaTimeFormatData() {
        ResourceBundle dateFormatData = this.localeData.getDateFormatData(this.locale);
        if ((dateFormatData instanceof ParallelListResourceBundle)) {
            this.localeData.setSupplementary((ParallelListResourceBundle)dateFormatData);
            return dateFormatData;
        }
        return dateFormatData;
    }
    
    private String getDateTimePattern(String str, String s, int n, String s2) {
        StringBuilder sb = new StringBuilder();
        if (str != null) {
            sb.append(str);
        }
        if (!"gregory".equals(s2)) {
            sb.append(s2).append('.');
        }
        sb.append(s);
        String string = sb.toString();
        String string2 = sb.insert(0, "DTP.").toString();
        this.removeEmptyReferences();
        LocaleResources.ResourceReference resourceReference = (LocaleResources.ResourceReference)this.cache.get(string2);
        Object o = LocaleResources.NULLOBJECT;
        if (resourceReference == null || (o = resourceReference.get()) == null) {
            ResourceBundle resourceBundle = (str != null) ? this.getJavaTimeFormatData() : this.localeData.getDateFormatData(this.locale);
            if (resourceBundle.containsKey(string)) {
                o = resourceBundle.getStringArray(string);
            }
            else {
                assert !string.equals(s);
                if (resourceBundle.containsKey(s)) {
                    o = resourceBundle.getStringArray(s);
                }
            }
            this.cache.put(string2, new LocaleResources.ResourceReference(string2, o, this.referenceQueue));
        }
        if (o == LocaleResources.NULLOBJECT) {
            assert str != null;
            return null;
        }
        else {
            return ((String[])(String[])o)[n];
        }
    }
    
    static {
        NULLOBJECT = new Object();
    }
    
    private static class ResourceReference extends SoftReference<Object>
    {
        private final String cacheKey;
        
        ResourceReference(String cacheKey, Object referent, ReferenceQueue<Object> q) {
            super(referent, q);
            this.cacheKey = cacheKey;
        }
        
        String getCacheKey() {
            return this.cacheKey;
        }
    }
}
